from .... pyaz_utils import call_az

def show(account, database_name, package_name, schema_name):
    return call_az("az dla catalog package show", locals())


def list(account, database_name, schema_name, count=None, filter=None, orderby=None, select=None, skip=None, top=None):
    return call_az("az dla catalog package list", locals())




from .... pyaz_utils import call_az

def show(account, assembly_name, database_name):
    return call_az("az dla catalog assembly show", locals())


def list(account, database_name, count=None, filter=None, orderby=None, select=None, skip=None, top=None):
    return call_az("az dla catalog assembly list", locals())




from .... pyaz_utils import call_az

def show(name, resource_group, system_topic_name, include_full_endpoint_url=None, include_static_delivery_attribute_secret=None):
    '''
    Get the details of an event subscription of a system topic.
    '''
    return call_az("az eventgrid system-topic event-subscription show", locals())


def delete(name, resource_group, system_topic_name, yes=None):
    '''
    Delete an event subscription of a system topic
    '''
    return call_az("az eventgrid system-topic event-subscription delete", locals())


def list(resource_group, system_topic_name, odata_query=None):
    '''
    List event subscriptions of a specific system topic.
    '''
    return call_az("az eventgrid system-topic event-subscription list", locals())


def create(name, resource_group, system_topic_name, advanced_filter=None, azure_active_directory_application_id_or_uri=None, azure_active_directory_tenant_id=None, deadletter_endpoint=None, delivery_attribute_mapping=None, enable_advanced_filtering_on_arrays=None, endpoint=None, endpoint_type=None, event_delivery_schema=None, event_ttl=None, expiration_date=None, included_event_types=None, labels=None, max_delivery_attempts=None, max_events_per_batch=None, preferred_batch_size_in_kilobytes=None, storage_queue_msg_ttl=None, subject_begins_with=None, subject_case_sensitive=None, subject_ends_with=None):
    '''
    Create a new event subscription for a system topic
    '''
    return call_az("az eventgrid system-topic event-subscription create", locals())


def update(name, resource_group, system_topic_name, advanced_filter=None, deadletter_endpoint=None, delivery_attribute_mapping=None, enable_advanced_filtering_on_arrays=None, endpoint=None, endpoint_type=None, included_event_types=None, labels=None, storage_queue_msg_ttl=None, subject_begins_with=None, subject_ends_with=None):
    '''
    Update an event subscription of a system topic.
    '''
    return call_az("az eventgrid system-topic event-subscription update", locals())




from ..... pyaz_utils import call_az

def show(name, resource_group, zone_name, record_type=None):
    '''
    Get the details of an MX record set.
    '''
    return call_az("az network dns record-set mx show", locals())


def delete(name, resource_group, zone_name, if_match=None, record_type=None, yes=None):
    '''
    Delete an MX record set and all associated records.
    '''
    return call_az("az network dns record-set mx delete", locals())


def list(resource_group, zone_name, record_type=None):
    '''
    List all MX record sets in a zone.
    '''
    return call_az("az network dns record-set mx list", locals())


def create(name, resource_group, zone_name, if_match=None, if_none_match=None, metadata=None, record_set_type=None, target_resource=None, ttl=None):
    '''
    Create an empty MX record set.
    '''
    return call_az("az network dns record-set mx create", locals())


def add_record(exchange, preference, record_set_name, resource_group, zone_name, if_none_match=None, ttl=None):
    '''
    Add an MX record.
    '''
    return call_az("az network dns record-set mx add-record", locals())


def remove_record(exchange, preference, record_set_name, resource_group, zone_name, keep_empty_record_set=None):
    '''
    Remove an MX record from its record set.
    '''
    return call_az("az network dns record-set mx remove-record", locals())


def update(name, resource_group, zone_name, add=None, force_string=None, if_match=None, if_none_match=None, metadata=None, record_type=None, remove=None, set=None, target_resource=None):
    '''
    Update an MX record set.
    '''
    return call_az("az network dns record-set mx update", locals())




from ..... pyaz_utils import call_az

def show(name, resource_group, zone_name, record_type=None):
    '''
    Get the details of an A record set.
    '''
    return call_az("az network private-dns record-set a show", locals())


def delete(name, resource_group, zone_name, if_match=None, record_type=None, yes=None):
    '''
    Delete an A record set and all associated records.
    '''
    return call_az("az network private-dns record-set a delete", locals())


def list(resource_group, zone_name, record_type=None):
    '''
    List all A record sets in a zone.
    '''
    return call_az("az network private-dns record-set a list", locals())


def create(name, resource_group, zone_name, metadata=None, record_type=None, ttl=None):
    '''
    Create an empty A record set.
    '''
    return call_az("az network private-dns record-set a create", locals())


def add_record(ipv4_address, record_set_name, resource_group, zone_name):
    '''
    Add an A record.
    '''
    return call_az("az network private-dns record-set a add-record", locals())


def remove_record(ipv4_address, record_set_name, resource_group, zone_name, keep_empty_record_set=None):
    '''
    Remove an A record from its record set.
    '''
    return call_az("az network private-dns record-set a remove-record", locals())


def update(name, resource_group, zone_name, add=None, force_string=None, if_match=None, metadata=None, record_type=None, remove=None, set=None):
    '''
    Update an A record set.
    '''
    return call_az("az network private-dns record-set a update", locals())

